@@ -1,18 +1,24 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Notennoù",
+    "Create new note" : "Krouiñ un notenn nevez",
     "Error" : "Fazi",
+    "New note" : "Notenn nevez",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Dilemel {number} notenn","Dilemel {number} notenn","Dilemel {number} notenn","Dilemel {number} notenn","Dilemel {number} notenn"],
     "Categories" : "Rummadoù",
-    "Share" : "Rannan",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
+    "Share" : "Rannan",
+    "Delete note" : "Dilemel an notenn",
     "Use current version" : "Implij stumm hiziv",
     "CTRL + /" : "CTRL + /",
     "Edit" : "Cheñch",
     "Preview" : "Ragwell",
-    "Loading …" : "O Kargañ ...",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
-    "This week" : "Er sizhun-mañ"
+    "This week" : "Er sizhun-mañ",
+    "Loading …" : "O Kargañ ...",
+    "Creating new note has failed." : "Krouiñ un notenn nevez 'neus c'hwitet."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
